summaryrefslogtreecommitdiff
path: root/python
diff options
context:
space:
mode:
authorJule Anger <ja@sernet.de>2020-08-27 09:20:11 +0200
committerDouglas Bagnall <dbagnall@samba.org>2020-10-01 02:44:09 +0000
commitab0e5e3c43165747d436269d5706e3736589c395 (patch)
treeefed4b407435d761a2f757a81431913929590be5 /python
parent3b7cf5f5dd99f55404848d2eb6c4b2ecb02607e7 (diff)
downloadsamba-ab0e5e3c43165747d436269d5706e3736589c395.tar.gz
samba-tool tests: rename 'contact create' to 'contact add'
Signed-off-by: Jule Anger <ja@sernet.de> Reviewed-by: Douglas Bagnall <douglas.bagnall@catalyst.net.nz> Reviewed-by: Gary Lockyer <gary@catalyst.net.nz> Autobuild-User(master): Douglas Bagnall <dbagnall@samba.org> Autobuild-Date(master): Thu Oct 1 02:44:09 UTC 2020 on sn-devel-184
Diffstat (limited to 'python')
-rw-r--r--python/samba/tests/samba_tool/contact.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/python/samba/tests/samba_tool/contact.py b/python/samba/tests/samba_tool/contact.py
index d8e0b873674..65f1a6857c9 100644
--- a/python/samba/tests/samba_tool/contact.py
+++ b/python/samba/tests/samba_tool/contact.py
@@ -70,7 +70,7 @@ class ContactCmdTestCase(SambaToolCmdTest):
self.assertCmdSuccess(result, out, err)
self.assertNotIn(
"ERROR", err, "There shouldn't be any error message")
- self.assertIn("Contact '%s' created successfully" %
+ self.assertIn("Contact '%s' added successfully" %
contact["expectedname"], out)
found = self._find_contact(contact["expectedname"])
@@ -101,7 +101,7 @@ class ContactCmdTestCase(SambaToolCmdTest):
self.assertCmdFail(result, "Succeeded to create existing contact")
self.assertIn("already exists", err)
# try to delete all the contacts we just created
for contact in self.contacts:
(result, out, err) = self.runsubcmd("contact", "delete", "%s" %
contact["expectedname"])
@@ -123,7 +123,7 @@ class ContactCmdTestCase(SambaToolCmdTest):
self.assertCmdSuccess(result, out, err)
self.assertEqual(err, "", "There shouldn't be any error message")
- self.assertIn("Contact '%s' created successfully" %
+ self.assertIn("Contact '%s' added successfully" %
contact["expectedname"], out)
found = self._find_contact(contact["expectedname"])
@@ -133,7 +133,7 @@ class ContactCmdTestCase(SambaToolCmdTest):
self.assertEqual("%s" % found.get("description"),
contact["description"])
# try to delete all the contacts we just created, by DN
for contact in self.contacts:
expecteddn = ldb.Dn(self.samdb,
"CN=%s,OU=%s,%s" %
@@ -161,7 +161,7 @@ class ContactCmdTestCase(SambaToolCmdTest):
self.assertCmdSuccess(result, out, err)
self.assertEqual(err, "", "There shouldn't be any error message")
- self.assertIn("Contact '%s' created successfully" %
+ self.assertIn("Contact '%s' added successfully" %
contact["expectedname"], out)
found = self._find_contact(contact["expectedname"])
@@ -101,7 +101,7 @@ class ContactCmdTestCase(SambaToolCmdTest):
self.assertCmdFail(result, "Succeeded to create existing contact")
self.assertIn("already exists", err)
- # try to delete all the contacts we just created
+ # try to delete all the contacts we just added
for contact in self.contacts:
(result, out, err) = self.runsubcmd("contact", "delete", "%s" %
@@ -133,7 +133,7 @@ class ContactCmdTestCase(SambaToolCmdTest):
self.assertEqual("%s" % found.get("description"),
contact["description"])
- # try to delete all the contacts we just created, by DN
+ # try to delete all the contacts we just added, by DN
for contact in self.contacts:
expecteddn = ldb.Dn(self.samdb,